// Indonesia 2007 (both expenditure and taxation contained within this file)

/* 
This do file calculates the following variables for each household
	hid     : household(hh) indentifier
	labor/money : a dummy which shows whether a household contributes labor/money
	Any     : a dummy which shows whether a household contribute labor OR money
	days    : the number of days contributed
	dollars : the amount of money contributed in local money and for specific duration (for Indonesia)
	hhsize  : the number of hh members (normally constructed from roster data)
	hhadults: number of adult members of hh (define as be older than 14)
	hhkids  : number of kids in hh (define as be between 4 and 14)
	hhbabies: number of babies of hh (define as be younger than 4)
	worker  : number of workers per household
	hhexp   : monthly household expenditure
	urban   : equal to one if hh lives in urban area and 0 otherwise
	weight  : the weight of hh which has to be considered
	cluster : is the indicator of smallest geographical unit, village or community  
	province: is the indicator of largest geographical unit, province or state
	_c and _b: suffix indicating the contribution toward cleaning and other activities, repectively
	weiclus : cluster level average of household weights
*/


clear
cap log close
set memo 500m
set more off
cd\IT 
log using "Results\ID07_Exp.log", replace

// Rates of taxation
gl alc_rate  = 0.75
gl tob_rate  = 0.30
gl fuel_rate = 0.
gl vat_rate  = 0.10
              
******************************************************************************************* Contributions
use  OData\ID07\Data3\R_PM14.dta, clear

// renaming the household id for consistency with other databases
ren rid hid

// dropping duplicate observations
duplicates drop          
 
sort       hid
tempfile 01 
save    `01'

****************************************Calculating the labor contribution
use OData\ID07\Data3\R.dta, clear

// renaming the household id for consistency with other databases
ren rid hid

// defining cluster
g   cc   = string(rlk01_cd,"%02.0f") + string(rlk02_cd,"%02.0f") +string(rlk03_cd,"%03.0f") +string(rlk04_cd,"%03.0f")
destring cc, generate(cluster) ignore(".")
format cluster %15.0f

// defining province variable
g    province =  rlk01_cd 

keep  hid cluster province rpm13 rpm10
sort  hid
merge hid using `01',uniqm
tab   _m
drop  _m

// defining abor contribution: the number of days and normal hours worked per day
ren  rpm15_n   n_days
ren  rpm15_h   n_hours
ren  rpm17_a   n_money
ren  rpm17_b   n_stuff 


// separating contributions toward cleaning (noted by _c) and other (by _b)

// creating dummy for labor contribution toward repair and construction, when rpm14type is equal to 2 (noted by _b)
g        labor_b  = rpm14type == 2 & rpm14 == 1 
replace  labor_b  = . if rpm10==.

// # of day and hours per day
g         days_b  = 0 if labor_b == 0

// changing the unit to working day as defined by 6-hour per day
replace   days_b  = n_days * n_hours /6  if rpm14type == 2 & rpm14 == 1 & days_b !=0
replace   days_b  = . if rpm10==.

// creating dummy for money contribution
g        money_b  = rpm14type == 2 & rpm16 == 1  
replace  money_b  = . if rpm10==.

/*Amount of money contribution, the sum of money and goods contribution. Add them up when both available and when only one of them is available use that one*/
g       dollars_b  = n_money  + n_stuff          if rpm14type  == 2 & rpm16    == 1 & n_money  !=. & n_stuff  !=.
replace dollars_b  = n_stuff                     if rpm14type  == 2 & rpm16    == 1 & n_money  ==. & n_stuff  !=.
replace dollars_b  = n_money                     if rpm14type  == 2 & rpm16    == 1 & n_money  !=. & n_stuff  ==.
replace dollars_b  = .                           if rpm14type  == 2 & rpm16    == 1 & n_stuff  ==. & n_money  ==.
replace dollars_b  = 0                           if money_b    == 0

/* Same process as above, here for contribution toward cleaning/maintenance activities, when rpm14type is equal to 1 (by _c) */
g        labor_c  = rpm14type == 1 & rpm14 == 1
replace  labor_c  = . if rpm10==.

g        days_c   = 0                            if labor_c == 0
replace  days_c   = n_days * n_hours /6          if rpm14type  == 1 & rpm14     == 1 & days_c !=0
replace  days_c   = . if rpm10==.

g        money_c  = rpm14type  == 1 & rpm16 == 1  
replace  money_c  = . if rpm10==.

/*Amount of money contribution, the sum of money and stuff contribution. Add them up when both available and when only one of them is available use that one*/
g       dollars_c  = n_money  + n_stuff          if rpm14type  == 1 & rpm16    == 1 & n_money  !=. & n_stuff  !=.
replace dollars_c  = n_stuff                     if rpm14type  == 1 & rpm16    == 1 & n_money  ==. & n_stuff  !=.
replace dollars_c  = n_money                     if rpm14type  == 1 & rpm16    == 1 & n_money  !=. & n_stuff  ==.
replace dollars_c  = .                           if rpm14type  == 1 & rpm16    == 1 & n_stuff  ==. & n_money  ==.
replace dollars_c  = 0                           if money_c    == 0

sort hid

// following separation o f contributions toward cleaning and other activity, summing up at hh level
collapse (max) labor*  money* days* dollars*, by(hid cluster province)

// defining the contribution regardless of the kind of activities are toward 
// then correcting for the case when both are missing, by replacing the result also as missing
g       labor  =       labor_c  == 1 |   labor_b   == 1
replace labor  = .  if labor_c  == . &   labor_b   == .
g       money  =       money_c  == 1 |   money_b   == 1
replace money  = .  if money_c  == . &   money_b   == .

g       days     = days_b  + days_c          if days_b     !=. & days_c     !=.
replace days     = days_b                    if days_b     !=. & days_c     ==.
replace days     = days_c                    if days_b     ==. & days_c     !=.
replace days     = .                         if days_b     ==. & days_c     ==.
g       dollars  = dollars_b  + dollars_c    if dollars_b  !=. & dollars_c  !=.
replace dollars  = dollars_b                 if dollars_b  !=. & dollars_c  ==.
replace dollars  = dollars_c                 if dollars_b  ==. & dollars_c  !=.
replace dollars  = .                         if dollars_b  ==. & dollars_c  ==.

// defining the variable "any": dummy for any kind of contribution
// then correcting for case when both are missing, by replacing result also as missing
g       any_c   =       labor_c  == 1  |   money_c   == 1
replace any_c   = .  if labor_c  == .  &   money_c   == .
g       any_b   =       labor_b  == 1  |   money_b   == 1
replace any_b   = .  if labor_b  == .  &   money_b   == .
g       any     =       any_b    == 1  |   any_c     == 1
replace any     = .  if any_b    == .  &   any_c     == .

// marking observations where two variables of labor and days contradict each other
g       contrad =0
replace contrad =1 if labor_b==0 & days_b>0 & days_b!=. 
replace contrad =1 if labor_b==1 & days_b==0
replace contrad =1 if labor_b==. & days_b>0 & days_b!=.
replace contrad =1 if labor_c==0 & days_c>0 & days_c!=. 
replace contrad =1 if labor_c==1 & days_c==0
replace contrad =1 if labor_c==. & days_c>0 & days_c!=.

/*Still also possible to have contradiction in aggregate level, given manner in which add up days: 0+.=0*/
replace contrad =1 if labor==0 & days>0 & days!=. 
replace contrad =1 if labor==1 & days==0
replace contrad =1 if labor==. & days>0 & days!=.

// marking observations where two variables of money and dollars contradict each other
replace contrad =1 if money_b==0 & dollars_b>0 & dollars_b!=. 
replace contrad =1 if money_b==1 & dollars_b==0
replace contrad =1 if money_b==. & dollars_b>0 & dollars_b!=.
replace contrad =1 if money_c==0 & dollars_c>0 & dollars_c!=. 
replace contrad =1 if money_c==1 & dollars_c==0
replace contrad =1 if money_c==. & dollars_c>0 & dollars_c!=.
/*Still also possible to have contradiction in aggregate level, given manner in which add up dollars: 0+.=0*/
replace contrad =1 if money==0 & dollars>0 & dollars!=. 
replace contrad =1 if money==1 & dollars==0
replace contrad =1 if money==. & dollars>0 & dollars!=.

sort hid
tempfile contribution
save    `contribution'

************************************************************** HHsize and kids/adults
use OData\ID07\Data3\R_AR_01, clear 
ren rid hid
g    age     = 2007 - rar04_yy		/*Survey has been conducted 2007, so 2007 - yearofbirth = age*/
keep hid  age

// creating dummies for each age-group
g adults =  age>14
g kids   =  age<=14 & age>4
g babies =  age<=4

// calculation the number of adults/kids/babies per hh
collapse (sum) hhadults=adults (sum) hhkids=kids (sum) hhbabies=babies, by(hid)
g    hhsize = hhadults + hhkids + hhbabies            

tempfile hhsize 
save    `hhsize'

***************************************************************Workers
use OData\ID07\Data3\R_AR_01, clear
ren rid hid
recode rar09 (1=1) (2/6 95=0) (missing=.), gen(worker)
collapse (sum) worker, by(hid) 
sort hid          
tempfile worker 
save    `worker'

************************************************************************************************** Expenditure
*********************************************Food_exp
use OData\ID07\Data3\R_KS1TYPE, clear

ren rid hid
// reshaping data to have one line per hh with all food expenditure on it
reshape wide rks01, i(hid) j(rks1type)
// Sum up all food expenditure
egen     t_food_exp  = rowtotal(rks*)
replace  t_food_exp  = . if mi(rks011) & mi(rks012) & mi(rks013) & mi(rks014) & mi(rks015) & mi(rks016) & mi(rks017) & mi(rks018) & mi(rks019) & mi(rks0110) & mi(rks0111) & mi(rks0112) & mi(rks0113) & mi(rks0114) & mi(rks0115)

// converting food exp to year bases
replace  t_food_exp  = 52 * t_food_exp  	                  

// keeping alcohol and tobacco exp separate for the formal tax estimation below
g        alcohol_exp = 52 * rks0114 
g        tobacco_exp = 52 * rks0115 
keep     hid *_exp

sort     hid
tempfile food_exp
save    `food_exp'

************************************************Non Food Exp
use OData\ID07\Data3\R_KS2TYPE.dta, clear
 
ren rid hid
keep     hid rks03 rks04 rks2type

g        nfood_exp  = rks04 

// if the annual non-food exp not available, using monthly measure and adjust it
replace  nfood_exp  = 12 * rks03 		if rks04==. & rks03!=. 

**********************************************************************************************Taxation
// creating indicator to separate different kinds of non-food expenditure regarding taxation
g        tax_vat_id  = 0

//setting equal to 1 for direct taxes paid by hh
replace  tax_vat_id  = 1 if 8 < rks2type & rks2type < 13

// setting equal to 2 for expenditure touched by VAT
replace  tax_vat_id  = 2 if rks2type == 7  | rks2type == 8 | rks2type < 4 | rks2type == 14  /*VAT bases*/

// summing up exp in each group 
collapse (sum) nfood_exp              , by (hid tax_vat_id)

// direct taxes paid
g        t_dirtax_exp  = nfood_exp if tax_vat_id == 1

// exp that included also a VAT
g        t_vatbase_exp = nfood_exp if tax_vat_id == 2

// other expenditure (e.g. health, education, etc.)
g        t_other_exp   = nfood_exp if tax_vat_id == 0

collapse (sum)t_other_exp t_vatbase_exp t_dirtax_exp, by (hid)

sort hid
merge hid using `food_exp',unique
tab  _m
drop _m
sort hid
merge hid using `worker',unique
tab  _m
drop _m
sort hid
merge hid using `hhsize',unique
tab  _m
drop _m
sort hid
merge hid using `contribution',unique
tab  _m
drop _m

************************************************
// creating a monthly total expenditure 
egen long hhexp        = rowtotal(t_*)
replace   hhexp        = hhexp/12          /*per month*/
g         pcexp        = (hhexp/hhsize)    /*per capita per month*/

// calculating amount of tax paid:
/*y=(1+t)x    =>     the amount of tax paid = tx = t/(1+t) * y*/

g         vat            = ($vat_rate/(1+$vat_rate))   * t_vatbase_exp
g         alcohol_tax    = ($alc_rate/(1+$alc_rate))   * alcohol_exp
g         tobacco_tax    = ($tob_rate/(1+$tob_rate))   * tobacco_exp   

replace   tobacco_tax    = 0 if tobacco_tax ==.
replace   alcohol_tax    = 0 if alcohol_tax ==.

// calculating total of indirect tax
g         tot_indir_tax  = vat  + alcohol_tax + tobacco_tax

// renaming for consistency 
ren       t_dirtax_exp   tot_dir_tax

// generating total tax= direct plus indirect
g	    tot_tax        = tot_dir_tax + tot_indir_tax

sort     cluster
tempfile 02
save    `02'

**************************************************
// defining urban/rural observations
use    OData\ID07\Data3\L.dta, clear
recode llk05 (3=0), gen(urban)
g        cc   = string(llk01_cd,"%02.0f") + string(llk02_cd,"%02.0f") +string(llk03_cd,"%03.0f") +string(llk04_cd,"%03.0f")
destring cc, generate(cluster) ignore(".")
format   cluster %15.0f
rename llk01_cd prov
rename llk02_cd kabu
rename llk03_cd keca
rename llk04_cd desa
keep     cluster urban prov kabu keca desa
duplicates drop				

sort   cluster
merge  cluster using `02',uniqm	
tab    _m
drop   _m

sort     hid
tempfile 03
save    `03'

******************************************************** Identifying nature of sampling method
use OData\ID07\Data3\R.dta, clear

// renaming the household id for consistency with other databases
ren rid hid

g        cc   = string(rlk01_cd,"%02.0f") + string(rlk02_cd,"%02.0f") +string(rlk03_cd,"%03.0f") 
destring cc,    generate(dd) ignore(".")
format   dd %15.0f

keep dd hid
order dd
sort dd
tempfile DD
save `DD'

******************************************
use OData\ID07\Data3\ea_list.dta, clear
cap drop *nm
g        cc = prov + kabu + keca
destring cc, generate(dd) ignore(".")
format   dd %15.0f
// "type" variable is "CCT community and household kecamatans"
keep dd type

sort dd
merge dd using `DD', uniqm
tab _
drop if _==1
drop _
drop dd
ren type SamplingMethod

sort   hid
merge  hid using `03',uniqm	
tab    _m
drop   _m

sort     hid
order     hid cluster province urban  any* labor* money* days* dollars* pcexp tot_tax tot_dir_tax tot_indir_tax hhexp t_* t_o* hh* worker
drop      alcohol_exp tobacco_exp vat  alcohol_tax tobacco_tax 

// retaining community CCT kecamatan only
keep if SamplingMethod ==3
drop Sam*

// dropping urban observations
keep if urban==0

sort     hid
tempfile 04
save    `04'

// keeping list of hid with contradictions
keep if contrad ==1
keep hid
sort hid
save Results\ID07_contrad.dta, replace

***********************************************************
use `04', clear
// dropping observations with contradictions
drop if contrad ==1
drop contrad

tempfile 05
save	`05'

use OData\ID07\Data3\Wrev\wrev\whh.dta
rename rid hid
rename whh weight
replace weight = 1/weight
keep hid weight
sort hid

merge hid using `05', sort
tab _m
drop if _m == 1
drop _m

bys cluster: egen weiclus = mean(weight)
sort hid
save Results\ID07_Exp, replace
save Results\ID07_Tax, replace 
log close