// Nigeria Living Standard Survey (NLSS) 2004

/* 
This do file calculates the following variables for each household
	hid     : household (hh) identifier
	labor   : a dummy which shows whether a household contributes labor
	days    : the number of days contributed
	hhsize  : the number of hh members (normally constructed from roster data)
	hhadults: number of adult members of hh (define as be older than 14)
	hhkids  : number of kids in hh (define as be between 4 and 14)
	hhbabies: number of babies of hh (define as be younger than 4)
	worker  : number of workers per household
	hhexp   : monthly household expenditure
	urban   : equal to one if hh lives in urban area and 0 otherwise
	weight  : the weight of hh to be considered
	cluster : is the indicator of smallest geographical unit, village or community  
	weiclus : cluster level average of household weights
*/

clear
cap log close
cd\IT
log using "Results\NG04_Exp.log", replace

set memo 50m
set more off

***********************************************************Workers
use "OData\NG04\Activity status and employment search in the last 7 days.dta", clear
g   hid   = string(state,"%02.0f") +string(ric,"%04.0f") +string(hhno,"%03.0f")

recode wrkprt (2=0), gen(worker)

collapse (sum) worker, by(hid)

sort hid
tempfile 00
save `00'

***********************************************************Labor
use "OData\NG04\social capital and community participation.dta"
g   hid   = string(state,"%02.0f") +string(ric,"%04.0f") +string(hhno,"%03.0f")	 
keep compropa comprog hid

g labor = 0
replace labor = 1 if compropa == 2 | compropa == 3 | compropa == 8   
label variable labor "labor contribution dummy"
/*Judgment call: Decision on inclusion of 2,3, and 8 and not 1*/

sort hid
tempfile 01
save `01'

***********************************************************
use "OData\NG04\total household expenditure.dta", clear

g   hid   = string(state,"%02.0f") +string(ric,"%04.0f") +string(hhno,"%03.0f")	 
keep hid ric state pid sector weightea popwt  fdtot nfdtot fdtotpr hhexp

// converting yearly to monthly expenditure
replace      hhexp   = hhexp/12

sort hid
merge hid using `01', uniqus
tab _
drop _

sort hid
merge hid using `00', sort
tab _m
drop _m

ren 	    sector    urban
//recoding rural from "2" to "0"
recode    urban     (2 = 0) 		
				
g cluster  = string(state,"%02.0f") +string(ric,"%04.0f") +string(urban,"%01.0f")			
ren 	    weightea  weight 													 

sort hid
tempfile 02
save `02'

*******************************************************Adults/kids
use "OData\NG04\household roaster for each person.dta",clear
g   hid   = string(state,"%02.0f") +string(ric,"%04.0f") +string(hhno,"%03.0f")	
ren   ageyear    age
keep  hid  age 

// creating dummies for each age-group
g adults =  age>14
g kids   =  age<=14 & age>4
g babies =  age<=4

// calculating number of adults/kids/babies per hh
collapse (sum) hhadults=adults (sum) hhkids=kids (sum) hhbabies=babies, by(hid)
g hhsize = hhadults+hhkids+hhbabies                   
	/*Almost always equal to variable hhsize already available
	in the data, e.g. "total household expenditure.dta", and compatible with other
	variables made from roster data. */ 

sort hid
merge hid using `02', unique
tab _

************************************************************
keep  cluster hid hhsize weight urban labor hh* worker
order cluster hid hhsize weight urban labor hh* worker

sum labor [aw=weight]

sum labor [aw=weight] if urban==1
sum labor [aw=weight] if urban==0

bys cluster: egen weiclus = mean(weight)
sort hid

save "Results\NG04_Exp", replace
log close
