/* "Table 6: Informal taxation vs. household expenditure"
   "Table 8: Labor and money payments" */

clear
cap log close
cd\

set mem 50m
set more off
cd\IT
do "DoFiles Public\0. AdoFiles\maketable5.ado"
cd\IT\Results

**********************************************************************
// country name variables
gl   AL_country  = "Albania"
gl   ET_country  = "Ethiopia"
gl   GU_country  = "Guatemala"
gl ID07_country  = "Indonesia 2007"
gl NG04_country  = "Nigeria 2004"
gl   NI_country  = "Nicaragua"
gl   PA_country  = "Panama"
gl   PH_country  = "Philippines"
gl  V02_country  = "Vietnam 2002"
gl   ZA_country  = "Zambia"


// parameters chosen to calculate the Equivalent to Scale (ES) households size based on Deaton and Olken works
gl alpha_s = 0.5
gl alpha_l = 0.6
gl teta    = 0.85

gl country_list   PH AL ET GU ID07 PA NG04 V02 NI ZA

// choosing expenditure variable on which will regress contributions
gl regressors logESexp   					

// choosing variable to indicate will keep coeff to export
gl coeff_kept logESexp   	    		

*****************************************************Tables 6 and 8: Panel A
gl N = 0

// contribution variables ("any" for those with both labor and money values, "labor" for those with just labor values available)
gl AL_LHS 				labor
gl ET_LHS 				labor
gl GU_LHS 				labor
gl ID07_LHS 	any labor money
gl NG04_LHS 			labor
gl NI_LHS 		any labor money
gl PA_LHS 		any labor money
gl PH_LHS 				labor     
gl V02_LHS 		any labor money 
gl ZA_LHS 		any labor money

foreach cty in $country_list{
	// loading data (already excluding implausible obs)	
	use "`cty'_keeplist.dta", replace
	disp "****$`cty'_country****"
	
	// defining expenditure variable
	g logESexp  = log(hhexp/((hhadults+$alpha_l*hhkids+$alpha_s*hhbabies)^$teta))

	g obs_country = "`cty'" in 1

	// regressing each category of contribution on expenditure
	foreach var in $`cty'_LHS {
		// defining variable to store obs count	
		g obs_count_uncond_`var' = .
		
		quie clogit `var' $regressors, group(cluster) cluster(cluster)
		if $N == 0{
			maketable5 using table6&8_panelA_dropobs, rhs($coeff_kept) varcol($`cty'_country)  varrow("`var'") replace
			replace obs_count_uncond_`var' = e(N) in 1	
			outsheet obs_country obs_count_uncond_`var' using table6&8_panelA_dropobs_obscount in 1, replace	
		}
		else{
			maketable5 using table6&8_panelA_dropobs, rhs($coeff_kept) varcol($`cty'_country) varrow("`var'") append
			replace obs_count_uncond_`var' = e(N) in 1
			outsheet obs_country obs_count_uncond_`var' using table6&8_panelA_dropobs_obscount_`cty' in 1, replace
			appendfile table6&8_panelA_dropobs_obscount_`cty'.out table6&8_panelA_dropobs_obscount.out			
		}
		gl N = 1
	}
}

***************************************************** Table 6: Panels B & C, Table 8: Panel B

gl country_list PH AL ET ID07 V02  
gl N=0

foreach cty in $country_list{	
	// loading data (already excluding implausible obs)	
	use "`cty'_ind_wage_predicted.dta", replace
	disp "****`cty'****"
  sort hid
	merge hid using "`cty'_keeplist.dta", sort
	keep if _m != 1

	// calculating predicted monetary value of the labor contribution of each household
	g labor_quan = (HHwage_Av_hat/21.7) * days

	// defining expenditure variable
	g logESexp   = log(hhexp/((hhadults+$alpha_l*hhkids+$alpha_s*hhbabies)^$teta))

  // defining variable to store obs count
	g obs_country = "`cty'" in 1
	g obs_count_uncond = .
	g obs_count_uncond_labor_quan = .
	g obs_count_uncond_dollars = .
	
	// fixed-effects poisson (Quasi-ML) regression with robust Standard Errors for monetized labor contribution	  
	quie xtpqml labor_quan $regressors, i(cluster) cluster(cluster)  
	if $N==0{
		maketable5 using table6&8_panelB&C_dropobs, rhs($coeff_kept) varcol($`cty'_country) varrow(labor) replace
		replace obs_count_uncond = e(N) in 1
		local obs_count_labor_quan = e(N)	
		outsheet obs_country obs_count_uncond using table6&8_panelB&C_dropobs_obscount in 1, replace	
	}
	else{
		maketable5 using table6&8_panelB&C_dropobs, rhs($coeff_kept) varcol($`cty'_country) varrow(labor) append
		local obs_count_labor_quan = e(N)
		replace obs_count_uncond = e(N) in 1
		outsheet obs_country obs_count_uncond using table6&8_panelB&C_dropobs_obscount_`cty' in 1, replace
	}

	// if have value of both dollars and days,

	// if have value of monetary contribution, repeat above for monetary contributions and sum of both
	capture confirm variable dollars
  if !_rc{
		g tot_cont = labor_quan + dollars
		quie xtpqml dollars $regressors, i(cluster) cluster(cluster)  
		maketable5 using table6&8_panelB&C_dropobs, rhs($coeff_kept) varcol($`cty'_country) varrow(money) append
		replace obs_count_uncond_dollars = e(N) in 1
		replace obs_count_uncond_labor_quan = `obs_count_labor_quan' in 1 		
		quie xtpqml tot_cont  $regressors, i(cluster) cluster(cluster)
		maketable5 using table6&8_panelB&C_dropobs, rhs($coeff_kept) varcol($`cty'_country) varrow(any) append  
		
		// for those with just labor use that for total, for those with both contribution types use total combined contribution
		replace obs_count_uncond = e(N) in 1
		outsheet obs_country obs_count_uncond obs_count_uncond_dollars obs_count_uncond_labor_quan using table6&8_panelB&C_dropobs_obscount_`cty' in 1, replace
		appendfile table6&8_panelB&C_dropobs_obscount_`cty'.out table6&8_panelB&C_dropobs_obscount.out
	}
	else{
		if $N==1{
			appendfile table6&8_panelB&C_dropobs_obscount_`cty'.out table6&8_panelB&C_dropobs_obscount.out
		}
	}	
	gl N=1
}

***************************************************** Table 6: Panel C

foreach cty in $country_list {	
	// loading data (already excluding implausible obs)	
	use "`cty'_ind_wage_predicted.dta", replace
	disp "****`cty'****"
	sort hid
	merge hid using "`cty'_keeplist.dta", sort
	keep if _m != 1

	// calculating predicted monetary value of the labor contribution of each household
	g labor_quan = (HHwage_Av_hat/21.7) * days

	// defining expenditure variable
	g logESexp   = log(hhexp/((hhadults+$alpha_l*hhkids+$alpha_s*hhbabies)^$teta))

	// for conditional analysis, keeping only households which contribute 
	capture confirm variable any
	if !_rc{
		keep if any == 1
	}
	else{
		keep if labor==1
	}	

 // defining variable to store obs count
	g obs_country = "`cty'" in 1
	g obs_count_cond = .
	
	// fixed-effects poisson (Quasi-ML) regression with robust Standard Errors for monetized labor contribution
	quie xtpqml labor_quan $regressors, i(cluster) cluster(cluster)  
	maketable5 using table6&8_panelB&C_dropobs, rhs($coeff_kept) varcol($`cty'_country) varrow(labor 2) append
	replace obs_count_cond = e(N) in 1
	outsheet obs_country obs_count_cond using table6&8_panelB&C_dropobs_obscount_cond_`cty' in 1, replace
		
	// if have value of monetary contribution, repeat above for monetary contributions and sum of both
	capture confirm variable dollars
  if !_rc{
		g tot_cont = labor_quan + dollars
		quie xtpqml dollars $regressors, i(cluster) cluster(cluster)  
		maketable5 using table6&8_panelB&C_dropobs, rhs($coeff_kept) varcol($`cty'_country) varrow(money 2) append		
		quie xtpqml tot_cont $regressors, i(cluster) cluster(cluster)
		maketable5 using table6&8_panelB&C_dropobs, rhs($coeff_kept) varcol($`cty'_country) varrow(any 2	) append  

		// for those with just labor use that for total, for those with both contribution types use total combined contribution
		replace obs_count_cond = e(N) in 1
		outsheet obs_country obs_count_cond using table6&8_panelB&C_dropobs_obscount_cond_`cty' in 1, replace
		appendfile table6&8_panelB&C_dropobs_obscount_cond_`cty'.out table6&8_panelB&C_dropobs_obscount.out
	}
	else{
		appendfile table6&8_panelB&C_dropobs_obscount_cond_`cty'.out table6&8_panelB&C_dropobs_obscount.out				
	}
}

cd\
cd\IT

